/*
* @license Apache-2.0
*
* Copyright (c) 2023 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

// TypeScript Version: 4.1

/**
* Tests if a value is a 1-dimensional ndarray-like object whose underlying data type is `complex128`.
*
* @param v - value to test
* @returns boolean indicating if a value is a 1-dimensional ndarray-like object whose underlying data type is `complex128`
*
* @example
* var Complex128Array = require( `@stdlib/array/complex128` );
* var ndarray = require( `@stdlib/ndarray/ctor` );
*
* var arr = ndarray( 'complex128', new Complex128Array( [ 0, 0, 0, 0, 0, 0, 0, 0 ] ), [ 4 ], [ 1 ], 0, 'row-major' );
*
* var bool = isComplex128VectorLike( arr );
* // returns true
*
* bool = isComplex128VectorLike( [] );
* // returns false
*/
declare function isComplex128VectorLike( v: any ): boolean;


// EXPORTS //

export = isComplex128VectorLike;
